@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for VineLinux 5.2's 2.6.27 kernel.
+# This is a kernel build script for VineLinux 4.2's 2.6.16 kernel.
 #
 
 die () {
@@ -10,33 +10,33 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.27-76vl5.src.rpm ]
+if [ ! -r kernel-2.6.16-76.51vl4.src.rpm ]
 then
-    wget http://updates.vinelinux.org/Vine-5.2/updates/SRPMS/kernel-2.6.27-76vl5.src.rpm || die "Can't download source package."
+    wget http://updates.vinelinux.org/Vine-4.2/updates/SRPMS/kernel-2.6.16-76.51vl4.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-2.6.27-76vl5.src.rpm || die "Can't install source package."
+rpm -ivh kernel-2.6.16-76.51vl4.src.rpm || die "Can't install source package."
 
 cd /usr/src/vine/SOURCES/ || die "Can't chdir to /usr/src/vine/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.9-20130310.tar.gz ]
+if [ ! -r ccs-patch-1.7.0-20090911.tar.gz ]
 then
-    wget -O ccs-patch-1.6.9-20130310.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/30297/ccs-patch-1.6.9-20130310.tar.gz' || die "Can't download patch."
+    wget http://osdn.dl.sourceforge.jp/tomoyo/43375/ccs-patch-1.7.0-20090911.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 cp -p /usr/src/vine/SPECS/kernel-2.6-vl.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-2.6-vl.spec
-+++ kernel-2.6-vl.spec
-@@ -27,7 +27,7 @@
- %define patchlevel 62
+--- kernel-2.6-vl.spec	2009-06-27 09:57:13.000000000 +0900
++++ kernel-2.6-vl.spec	2009-08-09 19:26:02.000000000 +0900
+@@ -23,7 +23,7 @@
+ %define sublevel 16
  %define kversion 2.6.%{sublevel}
  %define rpmversion 2.6.%{sublevel}
--%define release 76%{?_dist_release}
-+%define release 76%{?_dist_release}_tomoyo_1.6.9p4
+-%define release 76.51%{_dist_release}
++%define release 76.51%{_dist_release}_tomoyo_1.7.0
  
  %define make_target bzImage
- %define hdrarch %_target_cpu
-@@ -121,6 +121,9 @@
+ 
+@@ -100,6 +100,9 @@
  # to versions below the minimum
  #
  
@@ -46,27 +46,27 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -153,7 +156,7 @@
+@@ -126,7 +129,7 @@
  #
- %define kernel_prereq  fileutils, module-init-tools >= 3.6, initscripts >= 8.80, mkinitrd >= 5.1.19.6, kernel-firmware >= %{version}
+ %define kernel_prereq  fileutils, modutils >= 3.2.2 , initscripts >= 5.83, mkinitrd >= 4.2.1.8-0vl2.1
  
 -Name: kernel
 +Name: ccs-kernel
  Group: System Environment/Kernel
  License: GPLv2
  Version: %{rpmversion}
-@@ -848,6 +851,10 @@
+@@ -1145,6 +1148,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.9-20130310.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.27-vine-linux-5.diff
++tar -zxf %_sourcedir/ccs-patch-1.7.0-20090911.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.16-vine-linux-4.2.diff
 +
  cp %{SOURCE10} Documentation/
  
  # put Vine logo
-@@ -866,6 +873,9 @@
+@@ -1165,6 +1172,9 @@
  for i in *.config
  do 
  	mv $i .config 
